@@ -18,18 +18,18 @@ class Stock:
     ticker : str
         ticker of a stock; country code needs to be append after a dot for not
         Polish stocks, e.g, 'AAPL.US'
+    interval : str
+        single letter defining the interval for OHLC data:
+        d - day (default), w - weekly, m - monthly, q - quarterly, y - yearly
     _ohlc : pandas.DataFrame
         DataFrame with OHLC prices (open-high-low-close), and volume
     _fundamentals : dict
         dictionary with available fundamental information
     """
 
-    check_for_update = True  # if True OHLC data will be checked for updates
-    update_period = 24  # time in hours, how often data are checked for updates
-    update_hour = 20  # full hour after that the data are checked for update
-
-    def __init__(self, ticker: str):
+    def __init__(self, ticker: str, interval: str = 'd'):
         self.ticker = ticker
+        self.interval = interval
         self._ohlc = StockQuotes(ticker)
         self._fundamentals = Fundamentals(ticker)
 
@@ -38,10 +38,7 @@ class Stock:
         """
         Returns DataFrame with OHLC prices (open-high-low-close), and volume.
         """
-        StockQuotes.check_for_update = self.check_for_update
-        StockQuotes.update_period = self.update_period
-        StockQuotes.update_hour = self.update_hour
-        return self._ohlc.data
+        return self._ohlc.ohlc(interval=self.interval)
 
     @property
     def last_ohlc(self):
@@ -116,9 +113,11 @@ class Stock:
         output = volume.mean()
         return output
 
+    @property
     def heikinashi(self):
         # read from file
-        file_path = os.path.join(get_storage_dir(), f'{self.ticker}_heikinashi.csv')
+        file_path = os.path.join(get_storage_dir(),
+                                 f'{self.ticker}_heikinashi_{self.interval}.csv')
         use_storage = get_storage_status()
 
         if use_storage and os.path.exists(file_path):
