@@ -1,4 +1,5 @@
 import pandas as pd
+from datetime import date
 
 
 class Commission:
@@ -21,14 +22,26 @@ class Commission:
 
 
 class Wallet(Commission):
+    """
+    Class representing na investor wallet (broker account).
+
+    Attributes
+    ----------
+    money : float
+        value of money in the wallet
+    stocks : pandas.DataFrame
+        DataFrame with owned stocks information:
+        'Name' - name/ticker of stock,
+        'Volume' - count of given shares in wallet
+        'Purchase price' - purchase price
+        'Purchase date' - date of first purchase (position opening date)
+        'Price' - latest stock price
+    """
+
     def __init__(self, commission_rate: float, min_commission):
         super().__init__(commission_rate, min_commission)
         self.money = 0
-        self.stocks = pd.DataFrame(columns=['Name', 'Volume', 'Purchase price', 'Price'])
-
-    @property
-    def money(self) -> float:
-        return self.__money
+        self.stocks = pd.DataFrame(columns=['Name', 'Volume', 'Purchase price', 'Purchase date', 'Price'])
 
     @property
     def stocks(self) -> pd.DataFrame:
@@ -43,10 +56,6 @@ class Wallet(Commission):
     def total_value(self):
         return self.stocks_value + self.money
 
-    @money.setter
-    def money(self, pay_in: float):
-        self.__money = pay_in
-
     @stocks.setter
     def stocks(self, new_stocks: pd.DataFrame):
         self.__stocks = new_stocks
@@ -147,10 +156,21 @@ class Wallet(Commission):
         else:
             return None
 
-    def buy(self, name: str, volume: int, price: float) -> None:
+    def get_position_opening_date_for_stock(self, name: str):
+        """
+        Returns date of position opening for given stock (first purchase date).
+        """
+        idx = self.__get_stocks_index(name)
+        if idx is not None:
+            return self.stocks.loc[idx, 'Purchase date']
+        else:
+            return None
+
+    def buy(self, name: str, volume: int, price: float, purchase_date: date = date.today()) -> None:
         stock = pd.DataFrame({'Name': [name],
                               'Volume': [volume],
                               'Purchase price': [price],
+                              'Purchase date': [date],
                               'Price': [price]})
         self.__add__(stock)
 
